@@ -1,6 +1,8 @@
 #
 # Copyright (c) 2014 Cisco Systems, Inc
 #
+# Author:Pradeep Kilambi <pkilambi@cisco.com>
+#
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
 # a copy of the License at
@@ -13,19 +15,25 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
+from oslo.config import cfg
+
+from ceilometer.central import plugin
 from ceilometer import neutron_client
-from ceilometer.polling import plugin_base
+from ceilometer import plugin as base_plugin
 
 
-class _BaseServicesDiscovery(plugin_base.DiscoveryBase):
-    KEYSTONE_REQUIRED_FOR_SERVICE = 'neutron'
+cfg.CONF.import_group('service_types', 'ceilometer.neutron_client')
 
-    def __init__(self, conf):
-        super(_BaseServicesDiscovery, self).__init__(conf)
-        self.neutron_cli = neutron_client.Client(conf)
+
+class _BaseServicesDiscovery(base_plugin.DiscoveryBase):
+
+    def __init__(self):
+        super(_BaseServicesDiscovery, self).__init__()
+        self.neutron_cli = neutron_client.Client()
 
 
 class LBPoolsDiscovery(_BaseServicesDiscovery):
+    @plugin.check_keystone(cfg.CONF.service_types.neutron)
     def discover(self, manager, param=None):
         """Discover resources to monitor."""
 
@@ -35,6 +43,7 @@ class LBPoolsDiscovery(_BaseServicesDiscovery):
 
 
 class LBVipsDiscovery(_BaseServicesDiscovery):
+    @plugin.check_keystone(cfg.CONF.service_types.neutron)
     def discover(self, manager, param=None):
         """Discover resources to monitor."""
 
@@ -44,6 +53,7 @@ class LBVipsDiscovery(_BaseServicesDiscovery):
 
 
 class LBMembersDiscovery(_BaseServicesDiscovery):
+    @plugin.check_keystone(cfg.CONF.service_types.neutron)
     def discover(self, manager, param=None):
         """Discover resources to monitor."""
 
@@ -52,25 +62,8 @@ class LBMembersDiscovery(_BaseServicesDiscovery):
                 if i.get('status', None) != 'error']
 
 
-class LBListenersDiscovery(_BaseServicesDiscovery):
-    def discover(self, manager, param=None):
-        """Discover load balancer listener resources to monitor."""
-
-        listeners = self.neutron_cli.list_listener()
-        return [i for i in listeners
-                if i.get('operating_status', None) != 'error']
-
-
-class LBLoadBalancersDiscovery(_BaseServicesDiscovery):
-    def discover(self, manager, param=None):
-        """Discover load balancer resources to monitor."""
-
-        loadbalancers = self.neutron_cli.list_loadbalancer()
-        return [i for i in loadbalancers
-                if i.get('operating_status', None) != 'error']
-
-
 class LBHealthMonitorsDiscovery(_BaseServicesDiscovery):
+    @plugin.check_keystone(cfg.CONF.service_types.neutron)
     def discover(self, manager, param=None):
         """Discover resources to monitor."""
 
@@ -79,6 +72,7 @@ class LBHealthMonitorsDiscovery(_BaseServicesDiscovery):
 
 
 class VPNServicesDiscovery(_BaseServicesDiscovery):
+    @plugin.check_keystone(cfg.CONF.service_types.neutron)
     def discover(self, manager, param=None):
         """Discover resources to monitor."""
 
@@ -88,6 +82,7 @@ class VPNServicesDiscovery(_BaseServicesDiscovery):
 
 
 class IPSecConnectionsDiscovery(_BaseServicesDiscovery):
+    @plugin.check_keystone(cfg.CONF.service_types.neutron)
     def discover(self, manager, param=None):
         """Discover resources to monitor."""
 
@@ -96,6 +91,7 @@ class IPSecConnectionsDiscovery(_BaseServicesDiscovery):
 
 
 class FirewallDiscovery(_BaseServicesDiscovery):
+    @plugin.check_keystone(cfg.CONF.service_types.neutron)
     def discover(self, manager, param=None):
         """Discover resources to monitor."""
 
@@ -105,14 +101,8 @@ class FirewallDiscovery(_BaseServicesDiscovery):
 
 
 class FirewallPolicyDiscovery(_BaseServicesDiscovery):
+    @plugin.check_keystone(cfg.CONF.service_types.neutron)
     def discover(self, manager, param=None):
         """Discover resources to monitor."""
 
         return self.neutron_cli.fw_policy_get_all()
-
-
-class FloatingIPDiscovery(_BaseServicesDiscovery):
-    def discover(self, manager, param=None):
-        """Discover floating IP resources to monitor."""
-
-        return self.neutron_cli.fip_get_all()
