@@ -1,4 +1,3 @@
-# -*- encoding: utf-8 -*-
 #
 # Copyright Ericsson AB 2013. All rights reserved
 #
@@ -20,19 +19,15 @@
 """
 
 import datetime
-import logging
-import testscenarios
 
-from ceilometer.openstack.common import timeutils
+from oslo.utils import timeutils
+
+from ceilometer.alarm.storage import models
 from ceilometer.publisher import utils
 from ceilometer import sample
-from ceilometer.storage import models
 from ceilometer.tests.api import v2 as tests_api
 from ceilometer.tests import db as tests_db
 
-load_tests = testscenarios.load_tests_apply_scenarios
-
-LOG = logging.getLogger(__name__)
 
 admin_header = {"X-Roles": "admin",
                 "X-Project-Id":
@@ -112,8 +107,8 @@ class TestQueryMetersController(tests_api.FunctionalTest,
                                       + isotime + '"}}'})
 
         self.assertEqual(2, len(data.json))
-        for sample in data.json:
-            result_time = timeutils.parse_isotime(sample['timestamp'])
+        for sample_item in data.json:
+            result_time = timeutils.parse_isotime(sample_item['timestamp'])
             result_time = result_time.replace(tzinfo=None)
             self.assertTrue(result_time >= date_time)
 
@@ -121,8 +116,8 @@ class TestQueryMetersController(tests_api.FunctionalTest,
         data = self.post_json(self.url,
                               params={},
                               headers=non_admin_header)
-        for sample in data.json:
-            self.assertEqual("project-id1", sample['project_id'])
+        for sample_item in data.json:
+            self.assertEqual("project-id1", sample_item['project_id'])
 
     def test_non_admin_tenant_cannot_query_others_project(self):
         data = self.post_json(self.url,
@@ -141,8 +136,8 @@ class TestQueryMetersController(tests_api.FunctionalTest,
                                       '{"=": {"project_id": "project-id1"}}'},
                               headers=non_admin_header)
 
-        for sample in data.json:
-            self.assertEqual("project-id1", sample['project_id'])
+        for sample_item in data.json:
+            self.assertEqual("project-id1", sample_item['project_id'])
 
     def test_admin_tenant_sees_every_project(self):
         data = self.post_json(self.url,
@@ -150,8 +145,8 @@ class TestQueryMetersController(tests_api.FunctionalTest,
                               headers=admin_header)
 
         self.assertEqual(3, len(data.json))
-        for sample in data.json:
-            self.assertIn(sample['project_id'],
+        for sample_item in data.json:
+            self.assertIn(sample_item['project_id'],
                           (["project-id1", "project-id2", "project-id3"]))
 
     def test_admin_tenant_sees_every_project_with_complex_filter(self):
@@ -163,8 +158,8 @@ class TestQueryMetersController(tests_api.FunctionalTest,
                               headers=admin_header)
 
         self.assertEqual(2, len(data.json))
-        for sample in data.json:
-            self.assertIn(sample['project_id'],
+        for sample_item in data.json:
+            self.assertIn(sample_item['project_id'],
                           (["project-id1", "project-id2"]))
 
     def test_admin_tenant_sees_every_project_with_in_filter(self):
@@ -175,8 +170,8 @@ class TestQueryMetersController(tests_api.FunctionalTest,
                               headers=admin_header)
 
         self.assertEqual(2, len(data.json))
-        for sample in data.json:
-            self.assertIn(sample['project_id'],
+        for sample_item in data.json:
+            self.assertIn(sample_item['project_id'],
                           (["project-id1", "project-id2"]))
 
     def test_admin_tenant_can_query_any_project(self):
@@ -186,8 +181,8 @@ class TestQueryMetersController(tests_api.FunctionalTest,
                               headers=admin_header)
 
         self.assertEqual(1, len(data.json))
-        for sample in data.json:
-            self.assertIn(sample['project_id'], set(["project-id2"]))
+        for sample_item in data.json:
+            self.assertIn(sample_item['project_id'], set(["project-id2"]))
 
     def test_query_with_orderby(self):
         data = self.post_json(self.url,
@@ -203,8 +198,8 @@ class TestQueryMetersController(tests_api.FunctionalTest,
                                       '{"=": {"project": "project-id2"}}'})
 
         self.assertEqual(1, len(data.json))
-        for sample in data.json:
-            self.assertIn(sample['project_id'], set(["project-id2"]))
+        for sample_item in data.json:
+            self.assertIn(sample_item['project_id'], set(["project-id2"]))
 
     def test_query_with_field_name_resource(self):
         data = self.post_json(self.url,
@@ -212,8 +207,26 @@ class TestQueryMetersController(tests_api.FunctionalTest,
                                       '{"=": {"resource": "resource-id2"}}'})
 
         self.assertEqual(1, len(data.json))
-        for sample in data.json:
-            self.assertIn(sample['resource_id'], set(["resource-id2"]))
+        for sample_item in data.json:
+            self.assertIn(sample_item['resource_id'], set(["resource-id2"]))
+
+    def test_query_with_wrong_field_name(self):
+        data = self.post_json(self.url,
+                              params={"filter":
+                                      '{"=": {"unknown": "resource-id2"}}'},
+                              expect_errors=True)
+
+        self.assertEqual(400, data.status_int)
+        self.assertIn("is not valid under any of the given schemas", data.body)
+
+    def test_query_with_wrong_json(self):
+        data = self.post_json(self.url,
+                              params={"filter":
+                                      '{"=": "resource": "resource-id2"}}'},
+                              expect_errors=True)
+
+        self.assertEqual(400, data.status_int)
+        self.assertIn("Filter expression not valid", data.body)
 
     def test_query_with_field_name_user(self):
         data = self.post_json(self.url,
@@ -221,8 +234,8 @@ class TestQueryMetersController(tests_api.FunctionalTest,
                                       '{"=": {"user": "user-id2"}}'})
 
         self.assertEqual(1, len(data.json))
-        for sample in data.json:
-            self.assertIn(sample['user_id'], set(["user-id2"]))
+        for sample_item in data.json:
+            self.assertIn(sample_item['user_id'], set(["user-id2"]))
 
     def test_query_with_field_name_meter(self):
         data = self.post_json(self.url,
@@ -230,8 +243,8 @@ class TestQueryMetersController(tests_api.FunctionalTest,
                                       '{"=": {"meter": "meter.test"}}'})
 
         self.assertEqual(3, len(data.json))
-        for sample in data.json:
-            self.assertIn(sample['meter'], set(["meter.test"]))
+        for sample_item in data.json:
+            self.assertIn(sample_item['meter'], set(["meter.test"]))
 
     def test_query_with_lower_and_upper_case_orderby(self):
         data = self.post_json(self.url,
@@ -262,7 +275,16 @@ class TestQueryMetersController(tests_api.FunctionalTest,
                               params={"orderby": '[{"project_id": ""}]'},
                               expect_errors=True)
 
-        self.assertEqual(500, data.status_int)
+        self.assertEqual(400, data.status_int)
+        self.assertIn("does not match '(?i)^asc$|^desc$'", data.body)
+
+    def test_query_with_wrong_json_in_orderby(self):
+        data = self.post_json(self.url,
+                              params={"orderby": '{"project_id": "desc"}]'},
+                              expect_errors=True)
+
+        self.assertEqual(400, data.status_int)
+        self.assertIn("Order-by expression not valid: Extra data", data.body)
 
     def test_filter_with_metadata(self):
         data = self.post_json(self.url,
@@ -270,8 +292,8 @@ class TestQueryMetersController(tests_api.FunctionalTest,
                                       '{">=": {"metadata.util": 0.5}}'})
 
         self.assertEqual(2, len(data.json))
-        for sample in data.json:
-            self.assertTrue(sample["metadata"]["util"] >= 0.5)
+        for sample_item in data.json:
+            self.assertTrue(sample_item["metadata"]["util"] >= 0.5)
 
     def test_filter_with_negation(self):
         filter_expr = '{"not": {">=": {"metadata.util": 0.5}}}'
@@ -279,8 +301,8 @@ class TestQueryMetersController(tests_api.FunctionalTest,
                               params={"filter": filter_expr})
 
         self.assertEqual(1, len(data.json))
-        for sample in data.json:
-            self.assertTrue(float(sample["metadata"]["util"]) < 0.5)
+        for sample_item in data.json:
+            self.assertTrue(float(sample_item["metadata"]["util"]) < 0.5)
 
     def test_limit_should_be_positive(self):
         data = self.post_json(self.url,
@@ -330,7 +352,7 @@ class TestQueryAlarmsController(tests_api.FunctionalTest,
                                                            'op': 'eq',
                                                            'value':
                                                            project_id}]))
-                    self.conn.update_alarm(alarm)
+                    self.alarm_conn.update_alarm(alarm)
 
     def test_query_all(self):
         data = self.post_json(self.alarm_url,
@@ -421,8 +443,8 @@ class TestQueryAlarmsController(tests_api.FunctionalTest,
                                       '{"=": {"project": "project-id2"}}'})
 
         self.assertEqual(6, len(data.json))
-        for sample in data.json:
-            self.assertIn(sample['project_id'], set(["project-id2"]))
+        for sample_item in data.json:
+            self.assertIn(sample_item['project_id'], set(["project-id2"]))
 
     def test_query_with_field_user_in_orderby(self):
         data = self.post_json(self.alarm_url,
@@ -477,7 +499,7 @@ class TestQueryAlarmsHistoryController(
                                     "on_behalf_of": "project-id%d" % id,
                                     "timestamp": date}
 
-                    self.conn.record_alarm_change(alarm_change)
+                    self.alarm_conn.record_alarm_change(alarm_change)
 
     def test_query_all(self):
         data = self.post_json(self.url,
